generate_for_state

Function generate_for_state 

pub fn generate_for_state(state: State) -> Cep
Generates a random Cep within the range of a given state.

Each official segment is selected proportionally to its number of CEPs. This generation is not cryptographically secure.