Module rand

Module rand 

Small non-cryptographic random sources used by document generators.

Structs

SeededRng
A small deterministic random source initialized from a u64 seed.

Traits

RandomSource
A minimal source of random bits for document generation.